@@ -17,13 +17,13 @@ from rasterio.transform import Affine, guard_transform
 
 # These modules are imported from the Cython extensions, but are also import
 # here to help tools like cx_Freeze find them automatically
-from rasterio import _err, coords, enums
+from rasterio import _err, coords, enums, vfs
 
 # Classes in rasterio._io are imported below just before we need them.
 
 __all__ = [
     'band', 'open', 'drivers', 'copy', 'pad']
-__version__ = "0.31.0"
+__version__ = "0.32.0"
 
 log = logging.getLogger('rasterio')
 class NullHandler(logging.Handler):
