@@ -2,8 +2,8 @@ import json
 import logging
 from math import ceil
 import os
-import shutil
 import re
+import shutil
 
 import click
 import cligj
@@ -11,18 +11,27 @@ from cligj import (
     precision_opt, indent_opt, compact_opt, projection_geographic_opt,
     projection_mercator_opt, projection_projected_opt, sequence_opt,
     use_rs_opt, geojson_type_feature_opt, geojson_type_bbox_opt,
-    files_inout_arg, format_opt, geojson_type_collection_opt)
+    format_opt, geojson_type_collection_opt)
 
 from .helpers import coords, resolve_inout, write_features, to_lower
 from . import options
 import rasterio
 from rasterio.transform import Affine
 from rasterio.coords import disjoint_bounds
+from rasterio.warp import transform_bounds
 
 logger = logging.getLogger('rio')
 
 
 # Common options used below
+
+# Unlike the version in cligj, this one doesn't require values.
+files_inout_arg = click.argument(
+    'files',
+    nargs=-1,
+    type=click.Path(resolve_path=True),
+    metavar="INPUTS... OUTPUT")
+
 all_touched_opt = click.option(
     '-a', '--all', '--all_touched', 'all_touched',
     is_flag=True,
@@ -50,6 +59,7 @@ all_touched_opt = click.option(
               help='Inverts the mask, so that areas covered by features are'
                    'masked out and areas not covered are retained.  Ignored '
                    'if using --crop')
+@options.force_overwrite_opt
 @options.creation_options
 @click.pass_context
 def mask(
@@ -61,6 +71,7 @@ def mask(
         all_touched,
         crop,
         invert,
+        force_overwrite,
         creation_options):
 
     """Masks in raster using GeoJSON features (masks out all areas not covered
@@ -85,12 +96,14 @@ def mask(
     input raster.
     """
 
-    from rasterio.features import geometry_mask
+    from rasterio.tools.mask import mask as mask_tool
     from rasterio.features import bounds as calculate_bounds
 
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
+    logger = logging.getLogger('rio')
 
-    output, files = resolve_inout(files=files, output=output)
+    output, files = resolve_inout(
+        files=files, output=output, force_overwrite=force_overwrite)
     input = files[0]
 
     if geojson_mask is None:
@@ -113,7 +126,7 @@ def mask(
                                      param_hint='--geojson-mask')
 
         if 'features' in geojson:
-            geometries = (f['geometry'] for f in geojson['features'])
+            geometries = [f['geometry'] for f in geojson['features']]
         elif 'geometry' in geojson:
             geometries = (geojson['geometry'], )
         else:
@@ -122,62 +135,29 @@ def mask(
         bounds = geojson.get('bbox', calculate_bounds(geojson))
 
         with rasterio.open(input) as src:
-            # If y pixel value is positive, then invert y dimension in bounds
-            invert_y = src.affine.e > 0
-
-            src_bounds = src.bounds
-            if invert_y:
-                src_bounds = [src.bounds[0], src.bounds[3],
-                              src.bounds[2], src.bounds[1]]
-
-            has_disjoint_bounds = disjoint_bounds(bounds, src_bounds)
-
-            if crop:
-                if has_disjoint_bounds:
-
-                    raise click.BadParameter('not allowed for GeoJSON outside '
-                                             'the extent of the input raster',
-                                             param=crop, param_hint='--crop')
-
-                if invert_y:
-                    bounds = (bounds[0], bounds[3], bounds[2], bounds[1])
-
-                window = src.window(*bounds)
-                transform = src.window_transform(window)
-                (r1, r2), (c1, c2) = window
-                mask_shape = (r2 - r1, c2 - c1)
-            else:
-                if has_disjoint_bounds:
-                    click.echo('GeoJSON outside bounds of existing output '
-                               'raster. Are they in different coordinate '
-                               'reference systems?',
-                               err=True)
-
-                window = None
-                transform = src.affine
-                mask_shape = src.shape
-
-            mask = geometry_mask(
-                geometries,
-                out_shape=mask_shape,
-                transform=transform,
-                all_touched=all_touched,
-                invert=invert)
+            try:
+                out_image, out_transform = mask_tool(src, geometries,
+                                                     crop=crop, invert=invert,
+                                                     all_touched=all_touched)
+            except ValueError as e:
+                if e.args[0] == 'Input shapes do not overlap raster.':
+                    if crop:
+                        raise click.BadParameter('not allowed for GeoJSON '
+                                                 'outside the extent of the '
+                                                 'input raster',                                                                 param=crop,
+                                                 param_hint='--crop')
 
             meta = src.meta.copy()
             meta.update(**creation_options)
             meta.update({
                 'driver': driver,
-                'height': mask.shape[0],
-                'width': mask.shape[1],
-                'transform': transform
+                'height': out_image.shape[1],
+                'width': out_image.shape[2],
+                'transform': out_transform
             })
 
             with rasterio.open(output, 'w', **meta) as out:
-                for bidx in range(1, src.count + 1):
-                    img = src.read(bidx, masked=True, window=window)
-                    img.mask = img.mask | mask
-                    out.write_band(bidx, img.filled(src.nodatavals[bidx-1]))
+                out.write(out_image)
 
 
 # Shapes command.
@@ -303,7 +283,7 @@ def shapes(
                     if bidx is None:
                         msk = numpy.logical_or.reduce(msk).astype('uint8')
 
-                    # Possibly overidden below.
+                    # Possibly overridden below.
                     img = msk
 
                 # Read the band data unless the --mask option is given.
@@ -399,9 +379,10 @@ def shapes(
 @click.option('--fill', type=float, default=0,
               help='Fill value for all pixels not overlapping features.  Will '
               'be evaluated as NoData pixels for output.  Default: 0')
-@click.option('--property', type=str, default=None, help='Property in '
+@click.option('--property', 'prop', type=str, default=None, help='Property in '
               'GeoJSON features to use for rasterized values.  Any features '
               'that lack this property will be given --default_value instead.')
+@options.force_overwrite_opt
 @options.creation_options
 @click.pass_context
 def rasterize(
@@ -417,7 +398,8 @@ def rasterize(
         all_touched,
         default_value,
         fill,
-        property,
+        prop,
+        force_overwrite,
         creation_options):
 
     """Rasterize GeoJSON into a new or existing raster.
@@ -466,7 +448,8 @@ def rasterize(
 
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
 
-    output, files = resolve_inout(files=files, output=output)
+    output, files = resolve_inout(
+        files=files, output=output, force_overwrite=force_overwrite)
 
     has_src_crs = src_crs is not None
     src_crs = src_crs or 'EPSG:4326'
@@ -481,8 +464,8 @@ def rasterize(
     with rasterio.drivers(CPL_DEBUG=verbosity > 2):
 
         def feature_value(feature):
-            if property and 'properties' in feature:
-                return feature['properties'].get(property, default_value)
+            if prop and 'properties' in feature:
+                return feature['properties'].get(prop, default_value)
             return default_value
 
         with click.open_file(files.pop(0) if files else '-') as gj_f:
@@ -524,7 +507,7 @@ def rasterize(
                     fill = fill)
 
                 for bidx in range(1, meta['count'] + 1):
-                    data = out.read_band(bidx, masked=True)
+                    data = out.read(bidx, masked=True)
                     # Burn in any non-fill pixels, and update mask accordingly
                     ne = result != fill
                     data[ne] = result[ne]
@@ -627,7 +610,7 @@ def rasterize(
 @click.command(short_help="Write bounding boxes to stdout as GeoJSON.")
 # One or more files, the bounds of each are a feature in the collection
 # object or feature sequence.
-@click.argument('INPUT', nargs=-1, type=click.Path(exists=True))
+@click.argument('INPUT', nargs=-1, type=click.Path(exists=True), required=True)
 @precision_opt
 @indent_opt
 @compact_opt
@@ -678,22 +661,20 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
             for i, path in enumerate(input):
                 with rasterio.open(path) as src:
                     bounds = src.bounds
-                    xs = [bounds[0], bounds[2]]
-                    ys = [bounds[1], bounds[3]]
                     if dst_crs:
-                        xs, ys = rasterio.warp.transform(
-                            src.crs, {'init': dst_crs}, xs, ys)
+                        bbox = transform_bounds(src.crs,
+                                                dst_crs, *bounds)
                     elif projection == 'mercator':
-                        xs, ys = rasterio.warp.transform(
-                            src.crs, {'init': 'epsg:3857'}, xs, ys)
+                        bbox = transform_bounds(src.crs,
+                                                {'init': 'epsg:3857'}, *bounds)
                     elif projection == 'geographic':
-                        xs, ys = rasterio.warp.transform(
-                            src.crs, {'init': 'epsg:4326'}, xs, ys)
+                        bbox = transform_bounds(src.crs,
+                                                {'init': 'epsg:4326'}, *bounds)
+                    else:
+                        bbox = bounds
 
                 if precision >= 0:
-                    xs = [round(v, precision) for v in xs]
-                    ys = [round(v, precision) for v in ys]
-                bbox = [min(xs), min(ys), max(xs), max(ys)]
+                    bbox = [round(b, precision) for b in bbox]
 
                 yield {
                     'type': 'Feature',
@@ -701,11 +682,11 @@ def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
                     'geometry': {
                         'type': 'Polygon',
                         'coordinates': [[
-                            [xs[0], ys[0]],
-                            [xs[1], ys[0]],
-                            [xs[1], ys[1]],
-                            [xs[0], ys[1]],
-                            [xs[0], ys[0]] ]]},
+                            [bbox[0], bbox[1]],
+                            [bbox[2], bbox[1]],
+                            [bbox[2], bbox[3]],
+                            [bbox[0], bbox[3]],
+                            [bbox[0], bbox[1]]]]},
                     'properties': {
                         'id': str(i),
                         'title': path,
