@@ -19,12 +19,8 @@ from rasterio.transform import Affine
 @format_opt
 @options.bounds_opt
 @options.resolution_opt
-@click.option('--nodata', type=float, default=None,
-              help="Override nodata values defined in input datasets")
-@click.option('--force-overwrite', '-f', 'force_overwrite', is_flag=True,
-              type=bool, default=False,
-              help="Do not prompt for confirmation before overwriting output "
-                   "file")
+@options.nodata_opt
+@options.force_overwrite_opt
 @click.option('--precision', type=int, default=7,
               help="Number of decimal places of precision in alignment of "
                    "pixels")
@@ -46,6 +42,8 @@ def merge(ctx, files, output, driver, bounds, res, nodata, force_overwrite,
     and are otherwise taken from the first input file.
 
     Note: --res changed from 2 parameters in 0.25.
+
+    \b
       --res 0.1 0.1  => --res 0.1 (square)
       --res 0.1 0.2  => --res 0.1 --res 0.2  (rectangular)
     """
@@ -55,12 +53,8 @@ def merge(ctx, files, output, driver, bounds, res, nodata, force_overwrite,
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
     logger = logging.getLogger('rio')
 
-    output, files = resolve_inout(files=files, output=output)
-
-    if os.path.exists(output) and not force_overwrite:
-        raise click.ClickException(
-            "Output exists and won't be overwritten without the "
-            "`-f` option")
+    output, files = resolve_inout(
+        files=files, output=output, force_overwrite=force_overwrite)
 
     sources = [rasterio.open(f) for f in files]
     dest, output_transform = merge_tool(sources, bounds=bounds, res=res,
