@@ -1,15 +1,11 @@
 import json
 import logging
-import warnings
 
 import click
 
 import rasterio
 
 
-warnings.simplefilter('default')
-
-
 @click.command(short_help="Sample a dataset.")
 @click.argument('files', nargs=-1, required=True, metavar='FILE "[x, y]"')
 @click.option('-b', '--bidx', default=None, help="Indexes of input file bands.")
