@@ -1,14 +1,26 @@
 """Raster warping and reprojection"""
 
-from affine import Affine
+from __future__ import absolute_import
+from __future__ import division
+
 from math import ceil
+import warnings
+
+from affine import Affine
 import numpy as np
 
+import rasterio
 from rasterio._base import _transform
-from rasterio._warp import _transform_geom, _reproject, RESAMPLING
+from rasterio._warp import (_transform_geom, _reproject, Resampling,
+                            _calculate_default_transform)
 from rasterio.transform import guard_transform
 
 
+RESAMPLING = Resampling
+warnings.warn(
+    "RESAMPLING is deprecated, use Resampling instead.", DeprecationWarning)
+
+
 def transform(src_crs, dst_crs, xs, ys, zs=None):
     """
     Transform vectors of x, y and optionally z from source
@@ -150,7 +162,7 @@ def reproject(
         dst_transform=None,
         dst_crs=None,
         dst_nodata=None,
-        resampling=RESAMPLING.nearest,
+        resampling=Resampling.nearest,
         **kwargs):
     """
     Reproject a source raster to a destination raster.
@@ -195,13 +207,13 @@ def reproject(
         src_nodata, or 0 (GDAL default).
     resampling: int
         Resampling method to use.  One of the following:
-            RESAMPLING.nearest,
-            RESAMPLING.bilinear,
-            RESAMPLING.cubic,
-            RESAMPLING.cubic_spline,
-            RESAMPLING.lanczos,
-            RESAMPLING.average,
-            RESAMPLING.mode
+            Resampling.nearest,
+            Resampling.bilinear,
+            Resampling.cubic,
+            Resampling.cubic_spline,
+            Resampling.lanczos,
+            Resampling.average,
+            Resampling.mode
     kwargs:  dict, optional
         Additional arguments passed to transformation function.
 
@@ -211,6 +223,9 @@ def reproject(
         Output is written to destination.
     """
 
+    # Resampling guard.
+    _ = Resampling(resampling)
+
     if src_transform:
         src_transform = guard_transform(src_transform).to_gdal()
     if dst_transform:
@@ -238,8 +253,7 @@ def calculate_default_transform(
         bottom,
         right,
         top,
-        resolution=None,
-        densify_pts=21):
+        resolution=None):
     """
     Transforms bounds to destination coordinate system, calculates resolution
     if not provided, and returns destination transform and dimensions.
@@ -247,13 +261,8 @@ def calculate_default_transform(
 
     Destination transform is anchored from the left, top coordinate.
 
-    Destination width and height are calculated from the number of pixels on
-    each dimension required to fit the destination bounds.
-
-    If resolution is not provided, it is calculated using a weighted average
-    of the relative sizes of source width and height compared to the transformed
-    bounds (pixels are assumed to be square).
-
+    Destination width and height (and resolution if not provided), are
+    calculated using GDAL's method for suggest warp output.
 
     Parameters
     ----------
@@ -270,36 +279,50 @@ def calculate_default_transform(
         Bounding coordinates in src_crs, from the bounds property of a raster.
     resolution: tuple (x resolution, y resolution) or float, optional
         Target resolution, in units of target coordinate reference system.
-    densify_pts: uint, optional
-        Number of points to add to each edge to account for nonlinear
-        edges produced by the transform process.  Large numbers will produce
-        worse performance.  Default: 21 (gdal default).
 
     Returns
     -------
     tuple of destination affine transform, width, and height
+
+    Note
+    ----
+    Must be called within a raster.drivers() context
+
+    Some behavior of this function is determined by the
+    CHECK_WITH_INVERT_PROJ environment variable
+        YES: constrain output raster to extents that can be inverted
+             avoids visual artifacts and coordinate discontinuties.
+        NO:  reproject coordinates beyond valid bound limits
     """
+    dst_affine, dst_width, dst_height = _calculate_default_transform(
+        src_crs, dst_crs,
+        width, height,
+        left, bottom, right, top)
 
-    xmin, ymin, xmax, ymax = transform_bounds(
-        src_crs, dst_crs, left, bottom, right, top, densify_pts)
+    # If resolution is specified, Keep upper-left anchored
+    # adjust the transform resolutions
+    # adjust the width/height by the ratio of estimated:specified res (ceil'd)
+    if resolution:
 
-    x_dif = xmax - xmin
-    y_dif = ymax - ymin
-    size = float(width + height)
+        # resolutions argument into tuple
+        try:
+            res = (float(resolution), float(resolution))
+        except TypeError:
+            res = (resolution[0], resolution[0]) \
+                if len(resolution) == 1 else resolution[0:2]
 
-    if resolution is None:
-        # TODO: compare to gdalwarp default
-        avg_resolution = (
-            (x_dif / float(width)) * (float(width) / size) +
-            (y_dif / float(height)) * (float(height) / size)
-        )
-        resolution = (avg_resolution, avg_resolution)
+        # Assume yres is provided as positive,
+        # needs to be negative for north-up affine
+        xres = res[0]
+        yres = -res[1]
 
-    elif not isinstance(resolution, (tuple, list)):
-        resolution = (resolution, resolution)
+        xratio = dst_affine.a / xres
+        yratio = dst_affine.e / yres
 
-    dst_affine = Affine(resolution[0], 0, xmin, 0, -resolution[1], ymax)
-    dst_width = max(int(ceil(x_dif / resolution[0])), 1)
-    dst_height = max(int(ceil(y_dif / resolution[1])), 1)
+        dst_affine = Affine(xres, dst_affine.b, dst_affine.c,
+                            dst_affine.d, yres, dst_affine.f)
 
-    return dst_affine, dst_width, dst_height
\ No newline at end of file
+        dst_width = ceil(dst_width * xratio)
+        dst_height = ceil(dst_height * yratio)
+
+    return dst_affine, dst_width, dst_height
