@@ -127,12 +127,6 @@ class MockOption:
         self.name = name
 
 
-def test_like_dataset_callback(data):
-    ctx = MockContext()
-    info.like_handler(ctx, 'like', str(data.join('RGB.byte.tif')))
-    assert ctx.obj['like']['crs'] == {'init': 'epsg:32618'}
-
-
 def test_all_callback_pass(data):
     ctx = MockContext()
     ctx.obj['like'] = {'transform': 'foo'}
@@ -170,31 +164,6 @@ def test_transform_callback(data):
     assert info.transform_handler(ctx, MockOption('transform'), 'like') == 'foo'
 
 
-def test_nodata_callback_err(data):
-    ctx = MockContext()
-    ctx.obj['like'] = {'nodata': 'lolwut'}
-    with pytest.raises(click.BadParameter):
-        info.nodata_handler(ctx, MockOption('nodata'), 'lolwut')
-
-
-def test_nodata_callback_pass(data):
-    """Always return None if the value is None"""
-    ctx = MockContext()
-    ctx.obj['like'] = {'nodata': -1}
-    assert info.nodata_handler(ctx, MockOption('nodata'), None) is None
-
-
-def test_nodata_callback_0(data):
-    ctx = MockContext()
-    assert info.nodata_handler(ctx, MockOption('nodata'), '0') == 0.0
-
-
-def test_nodata_callback(data):
-    ctx = MockContext()
-    ctx.obj['like'] = {'nodata': -1}
-    assert info.nodata_handler(ctx, MockOption('nodata'), 'like') == -1.0
-
-
 def test_crs_callback_pass(data):
     """Always return None if the value is None"""
     ctx = MockContext()
@@ -513,7 +482,7 @@ def test_bounds_obj_bbox():
         '--precision', '2'
     ])
     assert result.exit_code == 0
-    assert result.output.strip() == '[-78.9, 23.56, -76.6, 25.55]'
+    assert result.output.strip() == '[-78.96, 23.56, -76.57, 25.55]'
 
 
 def test_bounds_compact():
@@ -526,7 +495,7 @@ def test_bounds_compact():
         '--compact'
     ])
     assert result.exit_code == 0
-    assert result.output.strip() == '[-78.9,23.56,-76.6,25.55]'
+    assert result.output.strip() == '[-78.96,23.56,-76.57,25.55]'
 
 
 def test_bounds_indent():
@@ -553,7 +522,7 @@ def test_bounds_obj_bbox_mercator():
     ])
     assert result.exit_code == 0
     assert result.output.strip() == (
-        '[-8782900.033, 2700489.278, -8527010.472, 2943560.235]')
+        '[-8789636.708, 2700489.278, -8524281.514, 2943560.235]')
 
 
 def test_bounds_obj_bbox_projected():
@@ -605,7 +574,7 @@ def test_bounds_seq():
     ])
     assert result.exit_code == 0
     assert result.output == (
-        '[-78.9, 23.56, -76.6, 25.55]\n[-78.9, 23.56, -76.6, 25.55]\n')
+        '[-78.96, 23.56, -76.57, 25.55]\n[-78.96, 23.56, -76.57, 25.55]\n')
     assert '\x1e' not in result.output
 
 
@@ -622,8 +591,7 @@ def test_bounds_seq_rs():
     ])
     assert result.exit_code == 0
     assert result.output == (
-        '\x1e[-78.9, 23.56, -76.6, 25.55]\n\x1e[-78.9, 23.56, -76.6, 25.55]\n')
-
+        '\x1e[-78.96, 23.56, -76.57, 25.55]\n\x1e[-78.96, 23.56, -76.57, 25.55]\n')
 
 def test_insp():
     runner = CliRunner()
